##  Setup in SAP LeanIX
In SAP LeanIX, you configure the SAP Signavio integration by providing user credentials for authentication. Then, you map fact sheets with SAP Signavio processes and dictionary items along with their attributes. Only users with admin rights can complete this setup in SAP LeanIX.
To configure the integration, follow these steps:
  1. In the Administration area, select Integrations. This opens the integrations area, where you can view existing integrations and add new ones.
  2. Click Add integrations. All available integrations that you can add are shown on the resulting page.
  3. Click Configure on SAP Signavio.
  4. Click New Configuration at the top of the page to open the integration configuration page for SAP Signavio.
  5. On the integration configuration page, enter the SAP Signavio user credentials to set up authentication. For a detailed guide, see [Setting Up Authentication](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c64207a441014b145d1ff0fd5f0f5__setting_up_authentication).
  6. Click Next to proceed to the Basic Configuration tab. In the Basic Configuration tab, define how the data should be synced by mapping fact sheets with SAP Signavio processes and dictionary items along with their attributes. For detailed guides, see [Mapping SAP Signavio Processes to Fact Sheets](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to map and sync processes from SAP Signavio to SAP LeanIX. Configure synchronization modes, set process hierarchy, and manage process attributes with field and value mapping.") and [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c67fd7a441014b2ec90b746a268b3__mapping_fact_sheets_and_dictionary_items-d26e44).
  7. Click Save to save the configuration, and click Sync Now to run the synchronization.
